/**
 ****************************************************************************
 * @file	D_Para_ch1.h
 * @brief	Motor vector control Parameter Header File for CH1
 * @version	V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#ifndef _D_PARA_CH1_H
#define _D_PARA_CH1_H


/*===================================================================*
	  Select parts
 *===================================================================*/
//#define	__USE_INAMP                                     /* If define __USE_INAMP, use internal amp */
//#define	__USE_ENCODER                                   /* Not supported on this board. */

/*===================================================================*
	  Board Parameter Definition
 *===================================================================*/
/* High/Low side driver logic */
#define	cPOLH_CH1					(1)					/* High side	 0:Low active, 1:High active */
#define	cPOLL_CH1					(1)					/* Low	side	 0:Low active, 1:High active */

/* V MAX */
#define	cV_MAX_CH1					(30.0f)				/* [V] Input voltage(Vdc)  at ADC =0xFFF0(5V) */

/* A MAX */
#define	cA_MAX_CH1					(5.0f)    			/* [A] Input current(Iabc) at ADC =0xFFF0(5V) */

/* Current detection Type */
#define cSHUNT_TYPE_CH1 			(3)					/* 1 : 1-shunt, 3 : 3-shunt */
#define	cBOOT_TYPE_CH1				(cBoot_i)			/* cBoot_i : Current control, cBoot_v: Volt control */

#define	cSHUNT_ZERO_OFFSET_CH1		(2.5f)				/* [V] Shunt ad offset voltage (shunt ad voltage of 0A) */

/* AD Channel */
/* for External Amp */
#define	cADCH_CURRENT_U_CH1			(10)				/* AD channel for U-phase current of 3shunt */
#define	cADCH_CURRENT_V_CH1			(11)				/* AD channel for V-phase current of 3shunt */
#define	cADCH_CURRENT_W_CH1			(12)				/* AD channel for W-phase current of 3shunt */

#if !defined(__USE_INAMP)
#define	cADCH_CURRENT_IDC_CH1		(12) 				/* AD Channel for DC current of 1shunt */
#else /* __USE_INAMP */
/* for Internal Amp */
#define	cADCH_CURRENT_IDC_CH1		(16)				/* AD Channel for DC current of 1shunt */
#endif /* __USE_INAMP */

#define	cADCH_VDC_CH1				(9) 				/* AD Channel for power supply voltage */

/* Over current */
#define	cOVC_CH1					(4.5f)				/* [A] Over current  */

/* Over voltage */
#define	cVDC_MINLIM_CH1				(1.0f)				/* [V] Vdc min limit */
#define	cVDC_MAXLIM_CH1				(cV_MAX_CH1 - 1.0f)	/* [V] Vdc max limit */

/*===================================================================*
	  Motor Parameter Definition
 *===================================================================*/

/* PWM Parameter */
#define	cPWMPRD_CH1 				(64.0f)				/* [us] PWM Period */
#define	cDEADTIME_CH1				(0.5f)				/* [us] Dead time */
#define	cREPTIME_CH1				(1)					/* Repeat time */

/* External specification */
#define	cSPEED_ACT_MIN				(12)				/* [Hz] Min Target speed of motor */
#define	cSPEED_ACT_MAX				(200) 				/* [Hz] Max Target speed of motor */

#define	cID_ST_USER_ACT_CH1			(0.2f)				/* [A] Start current (Id) */
#define	cIQ_ST_USER_ACT_CH1			(0.1f)				/* [A] Start current (Iq) */

/* Motor Parameter */
#define	cMOTOR_R_CH1				(11.0f)				/* [Ohm] Winding resistance */
#define	cMOTOR_LQ_CH1				(7.0f)				/* [mH] q-axis inductance */
#define	cMOTOR_LD_CH1				(cMOTOR_LQ_CH1)		/* [mH] d-axis inductance */
#define	cPOLE_CH1					(4)					/* [Pole] Poles of the motor */

/* Control Gain constant */
#define	cID_KP_CH1					(0.0219f)			/* [V/A]  d-axis current control Proportinal gain */
#define	cID_KI_CH1					(70.30f)			/* [V/As] d-axis current control Integral gain */
#define	cIQ_KP_CH1					(cID_KP_CH1)		/* [V/A]  q-axis current control Proportinal gain */
#define	cIQ_KI_CH1					(cID_KI_CH1)		/* [V/As] q-axis current control Integral gain */

#define	cPOSITION_KP_CH1			(5.0f)				/* [Hz/V]  Position estimation Proportinal gain (Kp) */
#define	cPOSITION_KI_CH1			(25.0f)	    		/* [Hz/Vs] Position estimation Integral gain (Ki) */
#define	cSPEED_KP_CH1				(0.015f)		    /* [A/Hz]  Speed Control Proportinal gain */
#define	cSPEED_KI_CH1				(0.015f)			/* [A/Hzs] Speed Control Integral gain */

#define	cSPD_PI_PRD_CH1				(1)					/* Speed PI period */

#define	cFCD_UD_LIM_CH1				(15.0f)				/* [Hz/s] Limitation of the increase value (Forced Stage) */
#define	cSTD_UP_LIM_CH1				(10.0f)				/* [Hz/s] Limitation of the increase value (Steady Stage) */
#define	cSTD_DW_LIM_CH1				(10.0f)				/* [Hz/s] Limitation of the decrease value (Steady Stage) */

#define	cBOOT_LEN_CH1				(0.1f)				/* [s] Time of Bootstrap Stage */
#define	cINIT_LEN_CH1				(0.5f)				/* [s] Time of Positioning Stage */
#define	cINIT_WAIT_LEN_CH1			(0.5f)				/* [s] Time of Positioning wait time */
#define	cGOUP_DELAY_LEN_CH1			(0.01f)				/* [s] Time of Change-up delay time */

#define	cHZ_MAX_CH1 				(220.0f) 			/* [Hz] Maximum speed of motor */
#define	cHZ_MIN_CH1 				(40.0f)				/* [Hz] Minimam speed of motor */
														/* When set cHZ_MIN > S_speed_actx, not move Stage from Force */

#define	cHZ_SPWM_CH1				(100.0f)			/* [Hz] in Hz the rotating speed under which the shift PWM will work (for 1shunt )*/
#define	cMINPLS_CH1					(2.0f)				/* [us] Minimum Pulse (for 1shunt) */
#define	cMAXPLS_CH1					(cPWMPRD_CH1 * 0.9f)	/* [us] Maximum Pulse (for 3shunt) */

#define	cID_LIM_CH1 				(cOVC_CH1 * 0.9f)	/* [A] d-axis limitation current */
#define	cIQ_LIM_CH1 				(cOVC_CH1 * 0.9f) 	/* [A] q-axis limitation current */

#define	cINITIAL_POSITION_CH1		(0)					/* [deg] Initial position */


/* for Voltage control parameter */
#define	cVD_POS_CH1					(0.6f)				/* [V] Voltage of positioning */
#define	cSPD_COEF_CH1				(0.15f)				/* [-] Speed coefficient */
#define	cHZ_V2I_CH1					(100.0f)			/* [Hz] Speed of switching from voltage control to current control */

/* for Encoder parameter */
#define	cENC_PULSE_NUM_CH1			(2048)				/* [ppr] Number of Encoder pulse */
#define	cENC_DEG_ADJUST_CH1			(180) 				/* [deg] Adjust Z-phase,0deg of electrical-angle */

/* for Fixed Vdc parameter */
#define __FIXED_VDC_CH1 			(1)					/* Fixed Vdc 0:Input Vdc(J3P1 with 1-2 short), 1:Fixed Vdc(J3P1 with 2-3 short) */
#define	cVDC_CH1					(24.0f)				/* [V] Power Voltage */

/*===================================================================*/
/* Control period of motor */
#define	cCTRL_PRD_CH1				(cPWMPRD_CH1 * cREPTIME_CH1 * 1e-6)								/* [s] */
#define	cSPD_CTRL_PRD_CH1			(cSPD_PI_PRD_CH1 * cPWMPRD_CH1 * cREPTIME_CH1 * 1e-6)			/* [s] */


/*===================================================================*
	Parameter check
 *===================================================================*/
#if ((__LED_SW == 1) && (__PC_CH1 == 1))
#error __LED_SW and __PC_CH1 define error. Can not be 1 at the same time.
#endif

#if (!((cPOLH_CH1 == 0) || (cPOLH_CH1 == 1)))
#error cPOLH_CH1 define error. cPOLH_CH1 only 0 or 1.
#endif
#if (!((cPOLL_CH1 == 0) || (cPOLL_CH1 == 1)))
#error cPOLL_CH1 define error. cPOLL_CH1 only 0 or 1.
#endif

#if (!((cSHUNT_TYPE_CH1 == 1) || (cSHUNT_TYPE_CH1 == 3)))
#error cSHUNT_TYPE_CH1 define error. cSHUNT_TYPE_CH1 only 1 or 3.
#endif

#endif /* _D_PARA_CH1_H */

/*************************** END OF FILE **************************************/


